@@ -17,12 +17,12 @@ def get_files(**kwargs):
         if first_part == 'LICENSES':
             files.append(File(Path(metadata_directory, 'licenses', 'LICENSES', f.path.parts[1]), f.contents))
 
-        if first_part != kwargs['package_name']:
+        if f.path.parts[0] != 'src':
             continue
 
-        files.append(f)
+        files.append(File(Path(*f.path.parts[1:]), f.contents))
 
-    files.append(
+    files.extend((
         File(
             Path(metadata_directory, 'WHEEL'),
             f"""\
@@ -32,9 +32,7 @@ Root-Is-Purelib: true
 Tag: py2-none-any
 Tag: py3-none-any
 """,
-        )
-    )
-    files.append(
+        ),
         File(
             Path(metadata_directory, 'METADATA'),
             f"""\
@@ -44,8 +42,8 @@ Version: 0.0.1
 License-File: LICENSES/Apache-2.0.txt
 License-File: LICENSES/MIT.txt
 """,
-        )
-    )
+        ),
+    ))
 
     record_file = File(Path(metadata_directory, 'RECORD'), '')
     update_record_file_contents(record_file, files)
